API Reference
=============

.. toctree::

    gwcelery.celery
    gwcelery.tasks
    gwcelery.util

.. automodule:: gwcelery
.. data:: app

    The GWCelery application, an instance of :class:`celery.Celery`.
